%define dracutlibdir %{_prefix}/lib/dracut
%global __cargo_skip_build 0
%global __cargo_is_lib() false

Summary:        An implementation of the FIDO Device Onboard Specification written in rust
Name:           fido-device-onboard
Version:        0.4.10
Release:        8%{?dist}
License:        BSD
URL:            https://github.com/fedora-iot/fido-device-onboard-rs
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz
Source1:        %{name}-rs-%{version}-vendor-patched.tar.xz

Patch0001:      fdo-fix-tss-esapi-features.patch
# After rust-1.73, bail out an error when using cargo:: in custom build script
# See https://github.com/puiterwijk/rust-openssl-kdf/pull/16
# Use this patch until openssl-kdf updates crate
Patch0002:      fix_openssl-kdf_v0.4.1_print_error_after_rust-1.73.patch
Patch3000:      debug-profile.patch
Patch3001:      0001-chore-update-libcryptsetup-rs-to-0.8.patch
Patch3002:      fido-device-onboard-rs-add-loongarch64-support-for-nix.patch

ExclusiveArch:  %{rust_arches}

BuildRequires: rust cargo golang clang-devel rust-toolset
BuildRequires: openssl-devel >= 3.0.1-12 tpm2-tss-devel cryptsetup-devel
BuildRequires: systemd-rpm-macros

%description
%{summary}.

%package -n fdo-init
Summary: dracut module for device initialization
Requires: openssl-libs >= 3.0.1-12

%description -n fdo-init
%{summary}

%package -n fdo-owner-onboarding-server
Summary: FDO Owner Onboarding Server implementation
Requires: openssl-libs >= 3.0.1-12

%description -n fdo-owner-onboarding-server
%{summary}

%package -n fdo-rendezvous-server
Summary: FDO Rendezvous Server implementation

%description -n fdo-rendezvous-server
%{summary}

%package -n fdo-manufacturing-server
Summary: FDO Manufacturing Server implementation
Requires: openssl-libs >= 3.0.1-12

%description -n fdo-manufacturing-server
%{summary}

%package -n fdo-client
Summary: FDO Client implementation
Requires: openssl-libs >= 3.0.1-12
Requires: clevis clevis-luks cryptsetup

%description -n fdo-client
%{summary}

%package -n fdo-owner-cli
Summary: FDO Owner tools implementation

%description -n fdo-owner-cli
%{summary}

%package -n fdo-admin-cli
Summary: FDO admin tools implementation
Requires: fdo-manufacturing-server fdo-init fdo-client
Requires: fdo-rendezvous-server fdo-owner-cli
Requires: fdo-owner-onboarding-server

%description -n fdo-admin-cli
%{summary}

%prep
%setup -q -n %{name}-rs-%{version}
%autopatch 0001 -p1
%autopatch -m 3000 -M 3001 -p1
%cargo_prep -V 1

%autopatch 0002 -p1
%autopatch 3002 -p1

%build
%cargo_build

%install
install -D -m0755 -t %{buildroot}%{_libexecdir}/fdo target/release/fdo-client-linuxapp
install -D -m0755 -t %{buildroot}%{_libexecdir}/fdo target/release/fdo-manufacturing-client
install -D -m0755 -t %{buildroot}%{_libexecdir}/fdo target/release/fdo-manufacturing-server
install -D -m0755 -t %{buildroot}%{_libexecdir}/fdo target/release/fdo-owner-onboarding-server
install -D -m0755 -t %{buildroot}%{_libexecdir}/fdo target/release/fdo-rendezvous-server
install -D -m0755 -t %{buildroot}%{_libexecdir}/fdo target/release/fdo-serviceinfo-api-server
install -D -m0755 -t %{buildroot}%{_bindir} target/release/fdo-owner-tool
install -D -m0755 -t %{buildroot}%{_bindir} target/release/fdo-admin-tool
install -D -m0644 -t %{buildroot}%{_unitdir} examples/systemd/*
install -D -m0644 -t %{buildroot}%{_docdir}/fdo examples/config/*
mkdir -p %{buildroot}%{_sysconfdir}/fdo
install -D -m0755 -t %{buildroot}%{dracutlibdir}/modules.d/52fdo dracut/52fdo/module-setup.sh
install -D -m0755 -t %{buildroot}%{dracutlibdir}/modules.d/52fdo dracut/52fdo/manufacturing-client-generator
install -D -m0755 -t %{buildroot}%{dracutlibdir}/modules.d/52fdo dracut/52fdo/manufacturing-client-service

%post -n fdo-owner-onboarding-server
%systemd_post fdo-owner-onboarding-server.service
%systemd_post fdo-serviceinfo-api-server.service

%preun -n fdo-owner-onboarding-server
%systemd_preun fdo-owner-onboarding-server.service
%systemd_post fdo-serviceinfo-api-server.service

%postun -n fdo-owner-onboarding-server
%systemd_postun_with_restart fdo-owner-onboarding-server.service
%systemd_postun_with_restart fdo-serviceinfo-api-server.service

%post -n fdo-rendezvous-server
%systemd_post fdo-rendezvous-server.service

%preun -n fdo-rendezvous-server
%systemd_preun fdo-rendezvous-server.service

%postun -n fdo-rendezvous-server
%systemd_postun_with_restart fdo-rendezvous-server.service

%post -n fdo-manufacturing-server
%systemd_post fdo-manufacturing-server.service

%preun -n fdo-manufacturing-server
%systemd_preun fdo-manufacturing-server.service

%postun -n fdo-manufacturing-server
%systemd_postun_with_restart fdo-manufacturing-server.service

%post -n fdo-client
%systemd_post fdo-client-linuxapp.service

%preun -n fdo-client
%systemd_preun fdo-client-linuxapp.service

%postun -n fdo-client
%systemd_postun_with_restart fdo-client-linuxapp.service

%post -n fdo-admin-cli
%systemd_post fdo-aio.service

%preun -n fdo-admin-cli
%systemd_preun fdo-aio.service

%postun -n fdo-admin-cli
%systemd_postun_with_restart fdo-aio.service

%files -n fdo-init
%license LICENSE
%{dracutlibdir}/modules.d/52fdo/*
%{_libexecdir}/fdo/fdo-manufacturing-client

%files -n fdo-owner-onboarding-server
%license LICENSE
%{_libexecdir}/fdo/fdo-owner-onboarding-server
%{_libexecdir}/fdo/fdo-serviceinfo-api-server
%dir %{_docdir}/fdo
%{_docdir}/fdo/device_specific_serviceinfo.yml
%{_docdir}/fdo/serviceinfo-api-server.yml
%{_docdir}/fdo/owner-onboarding-server.yml
%{_unitdir}/fdo-serviceinfo-api-server.service
%{_unitdir}/fdo-owner-onboarding-server.service

%files -n fdo-rendezvous-server
%license LICENSE
%dir %{_docdir}/fdo
%{_docdir}/fdo/rendezvous-*.yml
%{_libexecdir}/fdo/fdo-rendezvous-server
%{_unitdir}/fdo-rendezvous-server.service

%files -n fdo-manufacturing-server
%license LICENSE
%{_libexecdir}/fdo/fdo-manufacturing-server
%{_docdir}/fdo/manufacturing-server.yml
%{_unitdir}/fdo-manufacturing-server.service

%files -n fdo-client
%license LICENSE
%{_libexecdir}/fdo/fdo-client-linuxapp
%{_unitdir}/fdo-client-linuxapp.service

%files -n fdo-owner-cli
%license LICENSE
%{_bindir}/fdo-owner-tool

%files -n fdo-admin-cli
%license LICENSE
%{_bindir}/fdo-admin-tool
%{_unitdir}/fdo-aio.service
%dir %{_sysconfdir}/fdo

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.10-8
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.10-7
- Rebuilt for loongarch release

* Sat Jun 1 2024 Pengda Dou <doupengda@loongson.cn> - 0.4.10-6
- [Type] other
- [DESC] add longarch64 support for nix

* Mon Dec 25 2023 luffyluo <luffyluo@tencent.com> - 0.4.10-5
- Rebuilt for llvm 17.0.6

* Tue Oct 24 2023 Wang Guodong <gordonwwang@tencent.com> - 0.4.10-4
- fix openssl-kdf v0.4.1 print error after rust-1.73

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.10-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 18 2023 cunshunxia <cunshunxia@tencent.com> - 0.4.10-2
- Rebuilt for tpm2-tss 4.0.1

* Mon Jul 17 2023 Shuo Wang <abushwang@tencent.com> - 0.4.10-1
- update to 0.4.10

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.5-5
- Rebuilt for OpenCloudOS Stream 23.05

* Mon Apr 03 2023 cunshunxia <cunshunxia@tencent.com> - 0.4.5-4
- use rust-toolset instead of rust-packaging.

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.4.5-3
- Rebuilt for OpenCloudOS Stream 23

* Thu Dec 8 2022 Wang Guodong <gordonwwang@tencent.com> - 0.4.5-2
- rebuild for cargo-1.64.0(rust-1.64.0).

* Mon Nov 28 2022 cunshunxia <cunshunxia@tencent.com> - 0.4.5-1
- initial build
